GateResult class

The outcome of diffing a run's findings against a Baseline.

Constructors

GateResult({required List<Finding> newFindings, required List<Finding> knownFindings, required Set<String> resolvedFingerprints})
Creates a GateResult.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
knownFindings List<Finding>
Findings whose fingerprint is already accepted in the baseline.
final
newFindings List<Finding>
Findings whose fingerprint is not in the baseline — the regressions that fail the gate.
final
passed bool
Whether the run introduced no new findings.
no setter
resolvedFingerprints Set<String>
Baseline fingerprints no longer produced by the run — candidates to prune from the baseline.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited