expected property

List<ExpectedFinding> expected
final

The findings a human confirmed this case should produce. Empty for clean and adversarial cases, which must stay silent.

Implementation

final List<ExpectedFinding> expected;