ruleUnderTest property
The single rule this case isolates, or null for a CorpusCategory.realWorld case that runs every rule.
Implementation
final String? ruleUnderTest;
The single rule this case isolates, or null for a CorpusCategory.realWorld case that runs every rule.
final String? ruleUnderTest;