standard property
The standard pack to audit this case under. WCAG 2.2-only criteria only fire under Standard.wcag22, so a case for such a rule must select it.
Implementation
final Standard standard;
The standard pack to audit this case under. WCAG 2.2-only criteria only fire under Standard.wcag22, so a case for such a rule must select it.
final Standard standard;