GateViolation class

One reason the corpus gate failed.

Annotations
  • @experimental

Constructors

GateViolation(String ruleId, GateViolationKind kind, String message)
Creates a GateViolation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind GateViolationKind
Which gate condition was breached.
final
message String
A human-readable explanation.
final
ruleId String
The rule at fault.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited