expected property
The findings a human confirmed this case should produce. Empty for clean and adversarial cases, which must stay silent.
Implementation
final List<ExpectedFinding> expected;
The findings a human confirmed this case should produce. Empty for clean and adversarial cases, which must stay silent.
final List<ExpectedFinding> expected;